@@ -1,6 +1,5 @@
 import sys
 import time
-import orjson
 from argparse import ArgumentParser, Action
 from typing import List, Dict, Any, Optional, Union
 from os import PathLike
@@ -9,11 +8,6 @@ from logging import Logger
 from pydantic import BaseSettings
 
 
-def orjson_dumps(v, *, default):
-    # orjson.dumps returns bytes, to match standard json.dumps we need to decode
-    return orjson.dumps(v, default=default).decode()
-
-
 def namespaced_topic(topic: str, namespace: str = None) -> str:
     if namespace:
         return "{}/{}".format(namespace, topic)
@@ -21,6 +15,15 @@ def namespaced_topic(topic: str, namespace: str = None) -> str:
         return topic
 
 
+def parse_mappings(mappings: str) -> Dict[str, str]:
+    d = {}
+    if mappings:
+        for pair in mappings.split(","):
+            map_from, map_to = (n.strip() for n in pair.split(":"))
+            d[map_from] = map_to
+    return d
+
+
 StrPath = Union[str, PathLike]
 env_file_sentinel = str(object())
 
